#! /usr/bin/env bash

alias @assert=bluer_ai_assert

alias @badge=bluer_ai_badge

alias @browse=bluer_ai_browse

alias @cat=bluer_ai_cat

alias @code=bluer_ai_code

alias @env=bluer_ai_env

alias @eval=bluer_ai_eval

alias @help=bluer_ai_help

alias @hr=bluer_ai_hr

alias @list=bluer_ai_list

alias @log::list=bluer_ai_log_list

alias @not=bluer_ai_not

alias @open=bluer_ai_open

alias @option=bluer_ai_option
alias @option::int=bluer_ai_option_int
alias @option::choice=bluer_ai_option_choice

alias @options=bluer_options

alias @pause=bluer_ai_pause

alias @pylint=bluer_ai_pylint
alias @pytest=bluer_ai_pytest

alias @repeat=bluer_ai_repeat

alias @sleep=bluer_ai_sleep

alias @test=bluer_ai_test

alias @timestamp=bluer_ai_string_timestamp
alias @@timestamp=bluer_ai_string_timestamp_short

alias @today=bluer_ai_string_today

alias @wait=bluer_ai_wait

alias @watch=bluer_ai_watch
